======
People
======

Who are the people behind the cwepr package?

The first version of the cwepr package was implemented by Pascal Kirchner during his internship and masters thesis in 2018/19 at the University of Freiburg, supervised by Till Biskup, the author of the `ASpecD framework <https://www.aspecd.de/>`_ and maintainer of the cwepr package.

In autumn 2020, partly due to personal needs of the maintainer, development resumed, and Mirjam Schröder joined the development team. During this development and large-scale rewrite, portions of code from the `trepr package <https://docs.trepr.de/>`_ authored by J. Popp have been inherited.

Maintainer and master mind of the cwepr package is Till Biskup, the author of the `ASpecD framework <https://www.aspecd.de/>`_ the cwepr package is based upon.
